@@ -19,9 +19,9 @@ import (
 	"github.com/turbot/steampipe/pkg/db/db_local"
 	"github.com/turbot/steampipe/pkg/display"
 	"github.com/turbot/steampipe/pkg/error_helpers"
+	"github.com/turbot/steampipe/pkg/pluginmanager"
 	"github.com/turbot/steampipe/pkg/statushooks"
 	"github.com/turbot/steampipe/pkg/utils"
-	"github.com/turbot/steampipe/pluginmanager"
 )
 
 func serviceCmd() *cobra.Command {
@@ -180,6 +180,20 @@ func runServiceStartCmd(cmd *cobra.Command, _ []string) {
 		error_helpers.FailOnError(invoker.IsValid())
 	}
 
+	startResult, dashboardState, dbServiceStarted := startService(ctx, port, serviceListen, invoker)
+	alreadyRunning := !dbServiceStarted
+
+	printStatus(ctx, startResult.DbState, startResult.PluginManagerState, dashboardState, alreadyRunning)
+
+	if viper.GetBool(constants.ArgForeground) {
+		runServiceInForeground(ctx)
+	}
+}
+
+func startService(ctx context.Context, port int, serviceListen db_local.StartListenType, invoker constants.Invoker) (_ *db_local.StartResult, _ *dashboardserver.DashboardServiceState, dbServiceStarted bool) {
+	statushooks.Show(ctx)
+	defer statushooks.Done(ctx)
+
 	err := db_local.EnsureDBInstalled(ctx)
 	if err != nil {
 		exitCode = constants.ExitCodeServiceStartupFailure
@@ -199,6 +213,7 @@ func runServiceStartCmd(cmd *cobra.Command, _ []string) {
 		return
 	}
 
+	// if the service is already running, then service start should make the service persistent
 	if startResult.Status == db_local.ServiceAlreadyRunning {
 
 		// check that we have the same port and listen parameters
@@ -220,59 +235,27 @@ func runServiceStartCmd(cmd *cobra.Command, _ []string) {
 		}
 	}
 
-	// if the service was started
-	if startResult.Status == db_local.ServiceStarted {
-
-		//
-		// this is required since RefreshConnectionAndSearchPaths may end up
-		// displaying warnings
-		//
-		// At the moment warnings is implemented in error_helpers.ShowWarning
-		// which does not have access to the working context and in effect the
-		// status spinner
-		//
-		// TODO: fix this
-		statushooks.Done(ctx)
-		muteCtx := statushooks.DisableStatusHooks(ctx)
-
-		// do
-		err = db_local.RefreshConnectionAndSearchPaths(muteCtx, invoker)
-		if err != nil {
-			_, err1 := db_local.StopServices(ctx, false, constants.InvokerService)
-			if err1 != nil {
-				error_helpers.ShowError(ctx, err1)
-				exitCode = constants.ExitCodeServiceSetupFailure
-			}
-			error_helpers.FailOnError(err)
-		}
-	}
-
-	servicesStarted := startResult.Status == db_local.ServiceStarted
+	dbServiceStarted = startResult.Status == db_local.ServiceStarted
 
 	var dashboardState *dashboardserver.DashboardServiceState
 	if viper.GetBool(constants.ArgDashboard) {
 		dashboardState, err = dashboardserver.GetDashboardServiceState()
 		if err != nil {
 			tryToStopServices(ctx)
-			error_helpers.ShowError(ctx, err)
-			return
+			exitCode = constants.ExitCodeServiceStartupFailure
+			error_helpers.FailOnError(err)
 		}
 		if dashboardState == nil {
 			dashboardState, err = startDashboardServer(ctx)
 			if err != nil {
-				error_helpers.ShowError(ctx, err)
 				tryToStopServices(ctx)
-				return
+				exitCode = constants.ExitCodeServiceStartupFailure
+				error_helpers.FailOnError(err)
 			}
-			servicesStarted = true
+			dbServiceStarted = true
 		}
 	}
-
-	printStatus(ctx, startResult.DbState, startResult.PluginManagerState, dashboardState, !servicesStarted)
-
-	if viper.GetBool(constants.ArgForeground) {
-		runServiceInForeground(ctx)
-	}
+	return startResult, dashboardState, dbServiceStarted
 }
 
 func tryToStopServices(ctx context.Context) {
@@ -390,6 +373,17 @@ func runServiceRestartCmd(cmd *cobra.Command, _ []string) {
 		}
 	}()
 
+	dbStartResult, currentDashboardState := restartService(ctx)
+
+	if dbStartResult != nil {
+		printStatus(ctx, dbStartResult.DbState, dbStartResult.PluginManagerState, currentDashboardState, false)
+	}
+}
+
+func restartService(ctx context.Context) (_ *db_local.StartResult, _ *dashboardserver.DashboardServiceState) {
+	statushooks.Show(ctx)
+	defer statushooks.Done(ctx)
+
 	// get current db statue
 	currentDbState, err := db_local.GetState()
 	error_helpers.FailOnError(err)
@@ -448,24 +442,6 @@ to force a restart.
 		return
 	}
 
-	// this is required since RefreshConnectionAndSearchPaths may end up
-	// displaying warnings
-	//
-	// At the moment warnings is implemented in error_helpers.ShowWarning
-	// which does not have access to the working context and in effect the
-	// status spinner
-	//
-	// TODO: fix this
-	statushooks.Done(ctx)
-	muteCtx := statushooks.DisableStatusHooks(ctx)
-
-	// refresh connections
-	err = db_local.RefreshConnectionAndSearchPaths(muteCtx, constants.InvokerService)
-	if err != nil {
-		exitCode = constants.ExitCodeServiceSetupFailure
-		error_helpers.FailOnError(err)
-	}
-
 	// if the dashboard was running, start it
 	if currentDashboardState != nil {
 		err = dashboardserver.RunForService(ctx, dashboardserver.ListenType(currentDashboardState.ListenType), dashboardserver.ListenPort(currentDashboardState.Port))
@@ -476,7 +452,7 @@ to force a restart.
 		error_helpers.FailOnError(err)
 	}
 
-	printStatus(ctx, dbStartResult.DbState, dbStartResult.PluginManagerState, currentDashboardState, false)
+	return dbStartResult, currentDashboardState
 }
 
 func runServiceStatusCmd(cmd *cobra.Command, _ []string) {
@@ -627,7 +603,6 @@ to force a shutdown.
 		`)
 
 	}
-
 }
 
 func showAllStatus(ctx context.Context) {
